@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import os
 from datetime import datetime
 
 from django.conf import settings
@@ -35,14 +36,16 @@ from podcasting.utils.fields import AutoSlugField, UUIDField
 from podcasting.utils.twitter import can_tweet
 
 
-def get_show_upload_folder(self, filename):
-    "If requested, will make the path prexix a setting."
-    return "img/podcasts/{0}/{1}".format(self.slug, slugify(filename))
+def get_show_upload_folder(instance, pathname):
+    "A standardized pathname for uploaded files and images."
+    root, ext = os.path.splitext(pathname)
+    return "img/podcasts/{0}/{1}{2}".format(instance.slug, slugify(root), ext)
 
 
-def get_episode_upload_folder(self, filename):
-    "If requested, will make the path prexix a setting."
-    return "img/podcasts/{0}/episodes/{1}".format(self.show.slug, slugify(filename))
+def get_episode_upload_folder(instance, pathname):
+    "A standardized pathname for uploaded files and images."
+    root, ext = os.path.splitext(pathname)
+    return "img/podcasts/{0}/episodes/{1}{2}".format(instance.show.slug, slugify(root), ext)
 
 
 class Show(models.Model):
@@ -62,12 +65,17 @@ class Show(models.Model):
 
     site = models.ForeignKey(Site, default=settings.SITE_ID)
 
-    ttl = models.PositiveIntegerField(_("TTL"), default=1440,
+    ttl = models.PositiveIntegerField(_("ttl"), default=1440,
         help_text=_("""``Time to Live,`` the number of minutes a channel can be
         cached before refreshing."""))
-    webmaster = models.ForeignKey(User, related_name="webmaster",
-        help_text=_("""Remember to save the user"s name and e-mail address in the
-        <a href="../../../auth/user/">User application</a>."""))
+
+    owner = models.ForeignKey(User, related_name="podcast_shows",
+        help_text=_("""Make certain the user account has a name and e-mail address."""))
+
+    editor_email = models.EmailField(_("editor email"), blank=True,
+        help_text="Email address of the person responsible for the feed's content.")
+    webmaster_email = models.EmailField(_("webmaster email"), blank=True,
+        help_text="Email address of the person responsible for channel publishing.")
 
     license = LicenseField()
 
@@ -78,9 +86,11 @@ class Show(models.Model):
 
     enable_comments = models.BooleanField(default=True)
 
-    authors = models.ManyToManyField(User, related_name="show_authors",
-        help_text=_("""Remember to save the user's name and e-mail address in the
-        <a href="../../../auth/user/">User application</a>.<br />"""))
+    author_text = models.CharField("author text", max_length=255, help_text=_("""
+        This tag contains the name of the person or company that is most widely attributed to
+        publishing the Podcast and will be displayed immediately underneath the title of the Podcast.
+        The suggested format is: 'email@example.com (Full Name)' but 'Full Name' only, is acceptable.
+        Multiple authors should be comma separated."""))
 
     title = models.CharField(_("title"), max_length=255)
     slug = AutoSlugField(_("slug"), populate_from="title")
@@ -98,7 +108,7 @@ class Show(models.Model):
         irrelevant words in the itunes:summary, description, or
         itunes:keywords tags. This field can be up to 4000 characters."""))
 
-    original_image = models.ImageField(_("original image"), upload_to="img/podcasts/",
+    original_image = models.ImageField(_("original image"), upload_to=get_show_upload_folder,
         help_text=_("""An attractive, original square JPEG (.jpg) or PNG (.png)
         image of exactly 1000x1000 pixels at 72 pixels per inch. Image will be
         scaled down to 50x50 pixels at smallest in iTunes.<br /><br />
@@ -108,17 +118,17 @@ class Show(models.Model):
 
     if ImageSpec:
         admin_thumb_sm = ImageSpec([resize.Crop(50, 50)], image_field="original_image",
-                                    quality=100, pre_cache=True)
+                                   pre_cache=True, options={"quality": 100})
         admin_thumb_lg = ImageSpec([resize.Crop(450, 450)], image_field="original_image",
-                                    quality=100, pre_cache=True)
+                                   pre_cache=True, options={"quality": 100})
         img_show_sm = ImageSpec([resize.Crop(120, 120)], image_field="original_image",
-                                quality=100, pre_cache=True)
+                                pre_cache=True, options={"quality": 100})
         img_show_lg = ImageSpec([resize.Crop(550, 550)], image_field="original_image",
-                                quality=100, pre_cache=True)
+                                pre_cache=True, options={"quality": 100})
         img_itunes_sm = ImageSpec([resize.Crop(144, 144)], image_field="original_image",
-                                  quality=100, pre_cache=True)
+                                  pre_cache=True, options={"quality": 100})
         img_itunes_lg = ImageSpec([resize.Crop(1000, 1000)], image_field="original_image",
-                                  quality=100, pre_cache=True)
+                                  pre_cache=True, options={"quality": 100})
 
     feedburner = models.URLField(_("feedburner url"), blank=True,
         help_text=_("""Fill this out after saving this show and at least one
@@ -182,9 +192,10 @@ class Episode(models.Model):
 
     enable_comments = models.BooleanField(default=True)
 
-    authors = models.ManyToManyField(User, related_name="episode_authors",
-        help_text=_("""Remember to save the user's name and e-mail address in the
-        <a href="../../../auth/user/">User application</a>."""))
+    author_text = models.CharField("author text", max_length=255, help_text=_("""
+        The person or musician name(s) featured on this specific episode.
+        The suggested format is: 'email@example.com (Full Name)' but 'Full Name' only, is acceptable.
+        Multiple authors should be comma separated."""))
 
     title = models.CharField(_("title"), max_length=255)
     slug = AutoSlugField(_("slug"), populate_from="title")
@@ -217,17 +228,17 @@ class Episode(models.Model):
 
     if ImageSpec:
         admin_thumb_sm = ImageSpec([resize.Crop(50, 50)], image_field="original_image",
-                                 quality=100, pre_cache=True)
+                                   pre_cache=True, options={"quality": 100})
         admin_thumb_lg = ImageSpec([resize.Crop(450, 450)], image_field="original_image",
-                                    quality=100, pre_cache=True)
+                                   pre_cache=True, options={"quality": 100})
         img_episode_sm = ImageSpec([resize.Crop(120, 120)], image_field="original_image",
-                                   quality=100, pre_cache=True)
+                                   pre_cache=True, options={"quality": 100})
         img_episode_lg = ImageSpec([resize.Crop(550, 550)], image_field="original_image",
-                                   quality=100, pre_cache=True)
+                                   pre_cache=True, options={"quality": 100})
         img_itunes_sm = ImageSpec([resize.Crop(144, 144)], image_field="original_image",
-                                  quality=100, pre_cache=True)
+                                  pre_cache=True, options={"quality": 100})
         img_itunes_lg = ImageSpec([resize.Crop(1000, 1000)], image_field="original_image",
-                                  quality=100, pre_cache=True)
+                                  pre_cache=True, options={"quality": 100})
 
     hours = models.SmallIntegerField(_("hours"), max_length=2, default=0)
     minutes = models.SmallIntegerField(_("minutes"), max_length=2, default=0, choices=SIXTY_CHOICES)
@@ -325,7 +336,7 @@ class Enclosure(models.Model):
     size = models.PositiveIntegerField(_("size"), help_text=_("""The length attribute is the
         file size in bytes. Find this information in the files properties
         (on a Mac, ``Get Info`` and refer to the size row)"""))
-    mime = models.CharField(_("mime"), "Format", max_length=4, choices=MIME_CHOICES,
+    mime = models.CharField(_("mime format"), max_length=4, choices=MIME_CHOICES,
         default="mp3", help_text=_("Please contact support for a non mp3 filetype!"))
     bitrate = models.CharField(_("bit rate"), max_length=5, default="192",
         help_text=_("Measured in kilobits per second (kbps), often 128 or 192."))
